@@ -4,27 +4,62 @@
 from __future__ import annotations
 
 import os
-import sys
 import platform
-from typing import Any
+import sys
+from typing import Any, Optional
 
-from .library import Library
 from .hexadecimal import Hex
+from .library import Library
 from .utilities import Utilities
 
-TTY_AWARE = True
-IS_TTY = sys.stdout.isatty() and sys.stderr.isatty()
+# TTY_AWARE = True
+# IS_TTY = sys.stdout.isatty() and sys.stderr.isatty()
+# _win_vterm_mode = None
 
-_win_vterm_mode = None
+# pylint: disable=invalid-name
 
 
-class Colored:
+class Config:  # pylint: disable=[R0903]
 
-    def __init__(self, name: Any):
-        """ name can be str or int instead.
+    """ Config some global variables.
+
+    Attributes:
+        TTY_AWARE (bool): Description
+    """
+    TTY_AWARE: bool = True
+    WIN_VTERM_MODE: Optional[bool] = None
+
+    @staticmethod
+    def is_tty() -> bool:
+        """ Check if both sys.stdout and sys.stderr are connected to a TTY (terminal).
+
+        This function determines whether the script is running in an interactive
+        terminal or if the output has been redirected (e.g., to a file or pipe).
+
+        Returns:
+            bool: True if both stdout and stderr are attached to a TTY, False otherwise.
+
+        Example:
+            >>> is_tty()
+            True  # When running in a terminal
+
+            >>> python script.py > output.txt
+            False  # When stdout is redirected to a file
+        """
+        return sys.stdout.isatty() and sys.stderr.isatty()
+
+
+class Colored:  # pylint: disable=[R0902]
+
+    """ Colored class, it's the main class of managing
+    foreground, background and style colors.
+    """
+
+    def __init__(self, name: str | int):
+        """name can be str or int instead.
 
         Args:
-            name: name of color or number of color
+            name (Union[str, int]): name of color or number of color
         """
         self._name: str = str(name).lower()
         self._hex_color: str = ''
@@ -34,20 +69,20 @@ class Colored:
         self._ESC: str = Library.ESC
         self._END: str = Library.END
 
-        self._STYLES: dict = Library.STYLES
+        self._STYLES: dict[str, str] = Library.STYLES
         self._FOREGROUND_256: str = Library.FOREGROUND_256
         self._BACKGROUND_256: str = Library.BACKGROUND_256
 
-        self._COLORS: dict = Library.COLORS
-        self._HEX_COLORS: dict = Library.HEX_COLORS
+        self._COLORS: dict[str, str] = Library.COLORS
+        self._HEX_COLORS: dict[str, str] = Library.HEX_COLORS
         self._UNDERLINE_COLOR: str = Library.UNDERLINE_COLOR
 
         if self._name.startswith('#'):
-            self._hex_color: str = self._hex.find(self._name)
+            self._hex_color = self._hex.find(self._name)
 
         self.enable_windows_terminal_mode()
 
-    def attribute(self, line_color: str = '') -> str:
+    def attribute(self, line_color: str | int = '') -> str:
         """ Returns stylize text.
 
         Args:
@@ -64,14 +99,14 @@ class Colored:
             self._utils.is_style_exist(self._name)
 
             if self._name in ('underline', '4') and line_color:
-                line_color: str = str(line_color).lower()
+                line_color = str(line_color).lower()
                 self._utils.is_color_exist(line_color)
                 if not line_color.isdigit():
-                    line_color: str = self._COLORS[line_color]
+                    line_color = self._COLORS[line_color]
                 return f'{self._UNDERLINE_COLOR}{line_color}{self._END}'
 
             if not self._name.isdigit():
-                formatting: str = self._STYLES[self._name]
+                formatting = self._STYLES[self._name]
 
         return f'{self._ESC}{formatting}{self._END}'
 
@@ -85,9 +120,9 @@ class Colored:
             self._utils.is_color_exist(self._name)
 
             if self._name.startswith('#'):
-                color: str = self._hex_color
+                color = self._hex_color
             elif not self._name.isdigit():
-                color: str = self._COLORS[self._name]
+                color = self._COLORS[self._name]
 
         return f'{self._FOREGROUND_256}{color}{self._END}'
 
@@ -101,28 +136,31 @@ class Colored:
             self._utils.is_color_exist(self._name)
 
             if self._name.startswith('#'):
-                color: str = self._hex_color
+                color = self._hex_color
             elif not self._name.isdigit():
-                color: str = self._COLORS[self._name]
+                color = self._COLORS[self._name]
 
         return f'{self._BACKGROUND_256}{color}{self._END}'
 
     @staticmethod
     def enable_windows_terminal_mode() -> Any:
-        """ Contribution by: Andreas Fredrik Klasson, Magnus Heskestad,
+        """Contribution by: Andreas Fredrik Klasson, Magnus Heskestad,
         Dimitris Papadopoulos.
 
         Enable virtual terminal processing in Windows terminal. Does
         nothing if not on Windows. This is based on the rejected
         enhancement <https://bugs.python.org/issue29059>.
+
+        Returns:
+            Any: Description
         """
-        global _win_vterm_mode
-        if _win_vterm_mode is not None:
-            return _win_vterm_mode
+        # global _win_vterm_mode
+        if Config.WIN_VTERM_MODE is not None:
+            return Config.WIN_VTERM_MODE
 
         # Note: Cygwin should return something like 'CYGWIN_NT...'
-        _win_vterm_mode = platform.system().lower() == 'windows'
-        if _win_vterm_mode is False:
+        Config.WIN_VTERM_MODE = platform.system().lower() == 'windows'
+        if Config.WIN_VTERM_MODE is False:
             return
 
         from ctypes import windll, wintypes, byref, c_void_p
@@ -132,13 +170,13 @@ class Colored:
 
         hStdout = windll.kernel32.GetStdHandle(STD_OUTPUT_HANDLE)
         if hStdout == INVALID_HANDLE_VALUE:
-            _win_vterm_mode = False
+            Config.WIN_VTERM_MODE = False
             return
 
         mode = wintypes.DWORD(0)
         ok = windll.kernel32.GetConsoleMode(wintypes.HANDLE(hStdout), byref(mode))
         if not ok:
-            _win_vterm_mode = False
+            Config.WIN_VTERM_MODE = False
             return
 
         mode = wintypes.DWORD(mode.value | ENABLE_VIRTUAL_TERMINAL_PROCESSING)
@@ -149,7 +187,7 @@ class Colored:
             # To be more certain we could check kernel32.GetLastError
             # for STATUS_INVALID_PARAMETER, but since we only enable
             # one flag we can be certain enough.
-            _win_vterm_mode = False
+            Config.WIN_VTERM_MODE = False
             return
 
     @staticmethod
@@ -174,7 +212,7 @@ class Colored:
             return False
 
         # Also disable coloring when not printing to a TTY.
-        if TTY_AWARE and not IS_TTY:
+        if Config.TTY_AWARE and not Config.is_tty():
             return False
 
         # In all other cases, enable coloring.
@@ -289,7 +327,7 @@ def bg(name: int | str) -> str:
     return Colored(name).background()
 
 
-def stylize(text: str, formatting: int | str, reset=True) -> str:
+def stylize(text: str, formatting: int | str, reset: bool = True) -> str:
     """ Conveniently styles your text as and resets ANSI codes at its end.
 
     Args:
@@ -301,30 +339,33 @@ def stylize(text: str, formatting: int | str, reset=True) -> str:
         str: Formatting string text.
     """
     terminator: str = style('reset') if reset else ''
-    return f'{"".join(formatting)}{text}{terminator}'
+    return f'{"".join(str(formatting))}{text}{terminator}'
 
 
 def _c0wrap(formatting: str) -> str:
-    """ Contribution by brrzap.
+    """Contribution by brrzap.
     Wrap a set of ANSI styles in C0 control codes for readline safety.
 
     Args:
-        formatting: Sets the formatting (color or style) of the text.
+        formatting (str): Sets the formatting (color or style) of the text.
+
+    Returns:
+        str: Code formatting.
     """
     C0_SOH: str = '\x01'  # mark the beginning of nonprinting characters
     C0_STX: str = '\x02'  # mark the end of nonprinting characters
     return f'{C0_SOH}{"".join(formatting)}{C0_STX}'
 
 
-def stylize_interactive(text: str, formatting: str, reset=True) -> str:
-    """ Contribution by: Jay Deiman, brrzap
+def stylize_interactive(text: str, formatting: str, reset: bool = True) -> str:
+    """Contribution by: Jay Deiman, brrzap
     stylize() variant that adds C0 control codes (SOH/STX) for readline
     safety.
 
     Args:
-        text: String type text.
-        formatting: Sets the formatting (color or style) of the text.
-        reset: Reset the formatting style at its end, default is True.
+        text (str): String type text.
+        formatting (str): Sets the formatting (color or style) of the text.
+        reset (bool, optional): Reset the formatting style at its end, default is True.
 
     Returns:
         str: Formatting string text.
@@ -336,7 +377,7 @@ def stylize_interactive(text: str, formatting: str, reset=True) -> str:
     return f'{_c0wrap(formatting)}{text}{terminator}'
 
 
-def set_tty_aware(awareness=True) -> None:
+def set_tty_aware(awareness: bool = True) -> None:
     """ Contribution by: Andreas Motl, Jay Deiman
 
     Makes all interactions here tty aware. This means that if either
@@ -346,5 +387,6 @@ def set_tty_aware(awareness=True) -> None:
     Args:
         awareness: Default is True.
     """
-    global TTY_AWARE
-    TTY_AWARE = awareness
+    # global TTY_AWARE
+    # TTY_AWARE = awareness
+    Config.TTY_AWARE = awareness
